<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Model\Configure;

class ApplyAutoSetting extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;

    private Configure $model;

    public function __construct(Configure $model, ?Input $input = null)
    {
        $this->model = $model;
        parent::__construct($input, null);
    }

    public function execute(): bool
    {
        /** @var Input $input */
        $input = $this->getInput();
        $setting = (string) $input->get('autosetting', 's1');
        if (!\check_ajax_referer($setting, \false, \false)) {
            echo \json_encode(['success' => \false]);

            return \false;
        }
        $this->model->applyAutoSetting($setting);
        echo \json_encode(['success' => \true]);

        return \true;
    }
}
