<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Log\WordpressNoticeLogger;
use JchOptimize\Model\Cache;

use function JchOptimize\base64_decode_url;

class CleanCache extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;

    private Cache $model;

    public function __construct(Cache $model, ?Input $input = null)
    {
        $this->model = $model;
        parent::__construct($input, null);
    }

    public function execute(): bool
    {
        /** @var WordpressNoticeLogger $logger */
        $logger = $this->logger;

        /** @var Input $input */
        $input = $this->getInput();
        if ($this->model->cleanCache()) {
            $logger->success(\__('Cache deleted successfully!', 'jch-optimize'));
            $result = \true;
        } else {
            $logger->error(\__('Error cleaning cache!', 'jch-optimize'));
            $result = \false;
        }
        if (($return = (string) $input->get('return')) != '') {
            $redirect = base64_decode_url($return);
        } else {
            $redirect = 'options-general.php?page=jch_optimize';
        }
        \wp_redirect($redirect);

        return $result;
    }
}
