<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Joomla\Input\Input;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Core\Admin\Tasks;
use JchOptimize\Log\WordpressNoticeLogger;

class DeleteBackups extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;

    public function __construct(?Input $input = null)
    {
        parent::__construct($input);
    }

    public function execute(): bool
    {
        /** @var WordpressNoticeLogger $logger */
        $logger = $this->logger;
        $mResult = Tasks::deleteBackupImages();
        if (\false === $mResult) {
            $logger->error(\__('Failed trying to delete backup images', 'jch-optimize'));
            $result = \false;
        } elseif ('BACKUPPATHDOESNTEXIST' === $mResult) {
            $logger->warning(\__('The folder containing backup images wasn\'t created yet. Try optimizing some images first.', 'jch-optimize'));
            $result = \false;
        } else {
            $logger->success(\__('Successfully deleted backup images', 'jch-optimize'));
            $result = \true;
        }
        \wp_redirect('options-general.php?page=jch_optimize&tab=optimizeimages');

        return $result;
    }
}
