<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2023 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Controller;

use _JchOptimizeVendor\Joomla\Controller\AbstractController;
use _JchOptimizeVendor\Psr\Log\LoggerAwareInterface;
use _JchOptimizeVendor\Psr\Log\LoggerAwareTrait;
use JchOptimize\Log\WordpressNoticeLogger;
use JchOptimize\Model\BulkSettings;

class SetDefaultSettings extends AbstractController implements LoggerAwareInterface
{
    use LoggerAwareTrait;
    private BulkSettings $bulkSettings;

    public function __construct(BulkSettings $bulkSettings)
    {
        $this->bulkSettings = $bulkSettings;
    }

    public function execute(): bool
    {
        \check_admin_referer('jch_bulksettings');

        /** @var WordpressNoticeLogger $logger */
        $logger = $this->logger;
        if (\false !== $this->bulkSettings->setDefaultSettings()) {
            $logger->success(\__('Successfully restored default settings', 'jch-optimize'));
        } else {
            $logger->error(\__('Failed restoring default settings', 'jch-optimize'));
        }
        \wp_redirect('options-general.php?page=jch_optimize');

        return \true;
    }
}
