<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2020 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Html;

class TabContent
{
    public static function start(): string
    {
        return <<<HTML
<div class="tab-content">
\t<div style="display:none">
\t\t<fieldset>
\t\t\t<div>
HTML;
    }

    public static function addTab(string $id, bool $active = \false): string
    {
        $active = $active ? ' active' : '';

        return <<<HTML
\t\t\t</div>
\t\t</fieldset>
\t</div>\t\t
\t<div class="tab-pane{$active}" id="{$id}">
\t\t<fieldset style="display: none;">
\t\t\t<div>
HTML;
    }

    public static function addSection(string $header = '', string $description = '', string $class = ''): string
    {
        if (!empty($header)) {
            $header = <<<HMTL
<legend>{$header}</legend>
HMTL;
        }

        return <<<HTML
\t\t\t</div>
\t\t</fieldset>
\t\t<fieldset class="jch-group">
\t\t\t{$header}
\t\t\t<div class="{$class}"><p><em>{$description}</em></p></div>
\t\t\t<div>\t\t
HTML;
    }

    public static function end(): string
    {
        return <<<HTML
\t\t\t</div>
\t\t</fieldset>
\t</div>
</div>
HTML;
    }
}
