<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2022 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Platform;

use _JchOptimizeVendor\Joomla\Registry\Registry;

class Cache implements \JchOptimize\Core\Interfaces\Cache
{
    public static function cleanThirdPartyPageCache(): void
    {
        // Not currently used on this platform.
    }

    public static function prepareDataFromCache(?array $data): ?array
    {
        return $data;
    }

    public static function outputData(array $data): void
    {
        /** @psalm-var array{headers:string[], body:string} $data */
        if (!empty($data['headers'])) {
            foreach ($data['headers'] as $header) {
                \header($header);
            }
        }
        echo $data['body'];

        exit;
    }

    public static function getCacheStorage(Registry $params): string
    {
        // @var string
        return $params->get('pro_cache_storage_adapter', 'filesystem');
    }

    public static function isPageCacheEnabled(Registry $params, bool $nativeCache = \false): bool
    {
        return (bool) $params->get('cache_enable', '0');
    }

    public static function getCacheNamespace(bool $pageCache = \false): string
    {
        $id = '';
        if (\is_multisite()) {
            $id = \get_current_blog_id();
        }
        if ($pageCache) {
            return 'jchoptimizepagecache'.$id;
        }

        return 'jchoptimizecache'.$id;
    }

    public static function isCaptureCacheIncompatible(): bool
    {
        return \is_multisite();
    }
}
